@@ -3,10 +3,6 @@
 
 from pandagg.node.aggs.abstract import AggNode
 
-# necessary to ensure that all agg nodes are registered in metaclass
-from pandagg.node.aggs.bucket import *  # noqa
-from pandagg.node.aggs.pipeline import *  # noqa
-from pandagg.node.aggs.metric import *  # noqa
 from pandagg.node.types import MAPPING_TYPES
 
 from operator import itemgetter
