@@ -1,13 +1,16 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+from future.utils import iteritems
 from lighttree.exceptions import NotFoundNodeError
 
-from pandagg.node.mapping.abstract import Field, ShadowRoot, StringField, ComplexField
+from pandagg.node.mapping.abstract import (
+    Field,
+    UnnamedField,
+    UnnamedRegularField,
+    UnnamedComplexField,
+)
 
-# necessary to ensure all Fields are registered in meta-class
-import pandagg.node.mapping.field_datatypes as fd  # noqa
-import pandagg.node.mapping.meta_fields as mf  # noqa
 
 from pandagg.exceptions import (
     AbsentMappingFieldError,
@@ -19,25 +22,64 @@ from pandagg.tree._tree import Tree
 class Mapping(Tree):
 
     node_class = Field
+    KEY = None
 
     def __init__(self, *args, **kwargs):
         super(Mapping, self).__init__()
-        if (args and kwargs) or len(args) > 1:
+        if not kwargs and not args:
+            return
+        if len(args) > 1:
             raise ValueError(
                 "Invalid mapping declaration. Got:\n*args: %s\n**kwargs: %s"
                 % (args, kwargs)
             )
+
         if args:
             arg = args[0]
+            if arg is None:
+                # Mapping(None)
+                return
             if isinstance(arg, Mapping):
+                # Mapping(Mapping())
                 self.insert(arg)
-            elif arg is None:
-                pass
+                return
+            if isinstance(arg, dict):
+                # Mapping({"properties": {}})
+                kwargs = arg.copy()
             else:
-                # {'dynamic': False, 'properties': ...}
-                self.insert(ShadowRoot(**arg))
-        elif kwargs:
-            self.insert(ShadowRoot(**kwargs))
+                raise ValueError(
+                    "Wrong declaration: args %s, kwargs %s" % (args, kwargs)
+                )
+
+        # Mapping(dynamic=False, properties={...}}
+        properties = kwargs.pop("properties", None)
+        dynamic = kwargs.pop("dynamic", None)
+
+        # root
+        root_node = Field("_", "_", dynamic=dynamic)
+        self.insert_node(root_node)
+        if properties:
+            self._insert(root_node.identifier, properties, False)
+
+    def _insert(self, pid, el, is_subfield):
+        if not isinstance(el, dict):
+            raise ValueError("Wrong declaration, got %s" % el)
+        for name, field in iteritems(el):
+            if isinstance(field, dict):
+                field = field.copy()
+                field = UnnamedField.get_dsl_class(field.pop("type", "object"))(**field)
+            if not isinstance(field, UnnamedField):
+                raise ValueError("Unsupported type %s" % type(field))
+            node = field.to_named_field(name, _subfield=is_subfield)
+            self.insert_node(node, parent_id=pid)
+            if isinstance(field, UnnamedComplexField) and field.properties:
+                self._insert(node.identifier, field.properties, False)
+            if isinstance(field, UnnamedRegularField) and field.fields:
+                if is_subfield:
+                    raise ValueError(
+                        "Cannot insert subfields into a subfield on field %s" % name
+                    )
+                self._insert(node.identifier, field.fields, True)
 
     def __nonzero__(self):
         return not self.is_empty()
@@ -59,10 +101,10 @@ class Mapping(Tree):
                 )
         serialized_node = node.body
         if children_queries:
-            if isinstance(node, StringField):
-                serialized_node["fields"] = children_queries
-            elif isinstance(node, ComplexField):
+            if node.KEY in ("_", "object", "nested"):
                 serialized_node["properties"] = children_queries
+            else:
+                serialized_node["fields"] = children_queries
         return serialized_node
 
     def resolve_path_to_id(self, path):
